/*
 * Copyright 2002 Sun Microsystems, Inc.  All rights reserved.
 *
 * Use is subject to the GNU Lesser General Public License, Version 2.1,
 * February 1999, which is contained in the read-me file named
 * "README_GNU_LGPL." This library is free software; you can
 * redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software
 * Foundation; either version 2.1 of the License, or (at your
 * option) any later version. This library is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA.
 *
 *	File: 	messages.h
 *	Andrew Bose	
 *
 */

#include <libintl.h>
#define gettext_noop(String) (String)

unsigned char selstr[] =			gettext_noop("SELECT:         ");
unsigned char sysstr[] =			gettext_noop("  SYSTEM INFO   ");
unsigned char netstr[] =			gettext_noop(" SETUP NETWORK  ");
unsigned char offstr[] =			gettext_noop("   POWER DOWN   ");
unsigned char qoffstr[] =			gettext_noop("  POWER DOWN?   ");
unsigned char rebstr[] =			gettext_noop("     REBOOT     ");
unsigned char qrebstr[] =			gettext_noop("    REBOOT?     ");
unsigned char resnetstr[] =			gettext_noop(" RESET NETWORK  ");
unsigned char qresnetstr[] =		gettext_noop(" RESET NETWORK? ");
unsigned char resingnetstr[] =		gettext_noop("   RESETTING    ");
unsigned char resingnetstr2[] =		gettext_noop("    NETWORK     ");
unsigned char resfiltstr[] =		gettext_noop(" RESET FILTERS  ");
unsigned char qresfiltstr[] =		gettext_noop(" RESET FILTERS? ");
unsigned char resingfiltstr[] =		gettext_noop("   RESETTING    ");
unsigned char resingfiltstr2[] =	gettext_noop("    FILTERS     ");
unsigned char extstr[] =			gettext_noop("      EXIT      ");
unsigned char qextstr[] =			gettext_noop("     EXIT?      ");
unsigned char ynstr[] =				gettext_noop("  [Y]ES  [N]O   ");
unsigned char respwstr1[] =			gettext_noop("RESETTING ADMIN ");
unsigned char respwstr2[] =			gettext_noop("   PASSWORD     ");
unsigned char nullstr[] =			gettext_noop("                ");
unsigned char exstr[] =				gettext_noop("[S]AVE/[C]ANCEL ");
unsigned char finishstr[] =			gettext_noop("      SAVE      ");
unsigned char redostr[]   =			gettext_noop("      EDIT      ");
unsigned char ipstr[] =				gettext_noop("PRIMARY IP ADDR:");
unsigned char xipstr[] =			gettext_noop("INVALID IP:     ");
unsigned char ipaddrm[] =			gettext_noop("IP Address:     ");
unsigned char ipmess1[] =			gettext_noop(" PLEASE SAVE IP ");
unsigned char ipmess2[] =			gettext_noop("    ADDRESS     ");
unsigned char gwstr[] =				gettext_noop("ENTER GATEWAY:  ");
unsigned char xgwstr[] =			gettext_noop("INVALID GATEWAY:");
unsigned char nmstr[] =				gettext_noop("PRIMARY NETMASK:");
unsigned char xnmstr[] =			gettext_noop("INVALID NETMASK:");
unsigned char nmmess1[] =			gettext_noop("  PLEASE SAVE   ");
unsigned char nmmess2[] =			gettext_noop("    NETMASK     ");
unsigned char nsstr[] =				gettext_noop("ENTER DNS:      ");
unsigned char xnsstr[] =			gettext_noop("INVALID DNS:    ");
unsigned char verstr[] =			gettext_noop("VERIFYING:      ");
unsigned char savingstr[] =			gettext_noop("     SAVING     ");
unsigned char rebootingstr[] =		gettext_noop("SYSTEM REBOOTING");
unsigned char nonetstr[] =			gettext_noop("NO NETWORK FOUND");
unsigned char connectstr[] =		gettext_noop("[H]ALT [C]ONNECT");

unsigned char ipaddr[] =			gettext_noop("000.000.000.000");
unsigned char fipaddr[] =			gettext_noop("000.000.000.000");
unsigned char gwaddr[] =			gettext_noop("000.000.000.000");
unsigned char fgwaddr[] =			gettext_noop("000.000.000.000");
unsigned char nsaddr[] =			gettext_noop("000.000.000.000");
unsigned char fnsaddr[] =			gettext_noop("000.000.000.000");
unsigned char noip[] =				gettext_noop("000.000.000.000");
unsigned char defmaskA[] =			gettext_noop("255.000.000.000");
unsigned char defmaskB[] =			gettext_noop("255.255.000.000");
unsigned char defmaskC[] =			gettext_noop("255.255.255.000");
unsigned char defmask[] =			gettext_noop("255.255.255.000");
unsigned char fdefmask[] =			gettext_noop("255.255.255.000");
