/*
 * Copyright 2002 Sun Microsystems, Inc.  All rights reserved.
 *
 * Use is subject to the GNU Lesser General Public License, Version 2.1,
 * February 1999, which is contained in the read-me file named
 * "README_GNU_LGPL." This library is free software; you can
 * redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software
 * Foundation; either version 2.1 of the License, or (at your
 * option) any later version. This library is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA.
 */
/* button routines */

#include <stdio.h>
#include <stdlib.h>
#include "lcdutils.h"
#include "lcd_private.h"

int lcd_button_debounce(void *lcd_private) {
	struct lcd_private *lcd = lcd_private;
	return lcd->button_debounce;
}

int lcd_button_sense(void *lcd_private) {
	struct lcd_private *lcd = lcd_private;
	return lcd->button_sense;
}

/* wait until the user stops pressing a button */
void lcd_wait_no_button(void *lcd_private) {
	struct lcd_private *lcd = lcd_private;
	
	if (!lcd || lcd->fd < 0)
		return;
	
	ioctl(lcd->fd, BUTTON_Read, &lcd->display);
	lcd->display.buttons &= 0x00FF;
	while((lcd->display.buttons != BUTTON_NONE) && (lcd->display.buttons != BUTTON_NONE_B)) {
		ioctl(lcd->fd, BUTTON_Read, &lcd->display);
		lcd->display.buttons &= 0x00FF;
	}
}
